@@ -1,7 +1,7 @@
 use strict;
 
-require File::Spec;
-require File::Path;
+use File::Spec;
+use File::Path ();
 
 sub main_argv { local @ARGV = @_; main () } 
 
